@@ -292,7 +292,7 @@ def run_clang_format(repo_root, staged_files, list_of_changed_staged_files):
     return True
 
 
-def run_yapf_format(repo_root, staged_files, list_of_changed_staged_files):
+def run_yapf_format(repo_root, staged_files, list_of_changed_staged_files, yapf_file=None):
     """Runs yapf format on all python files staged for commit."""
 
     first_file_formatted = True
@@ -305,9 +305,11 @@ def run_yapf_format(repo_root, staged_files, list_of_changed_staged_files):
             # store the results into a patch file.
             yapf_format_path = ("/tmp/" + os.path.basename(os.path.normpath(repo_root)) + "_" +
                                 datetime.datetime.now().isoformat() + ".yapf.patch")
-            task = (YAPF_FORMAT_EXECUTABLE +
-                    " --style='{based_on_style: pep8, column_limit: 100}' -d " + staged_file +
-                    " > " + yapf_format_path)
+            if yapf_file is not None:
+                task = (YAPF_FORMAT_EXECUTABLE + " --style='" + yapf_file + "' -d " + staged_file +
+                        " > " + yapf_format_path)
+            else:
+                task = (YAPF_FORMAT_EXECUTABLE + " -d " + staged_file + " > " + yapf_format_path)
             run_command_in_folder(task, repo_root)
 
             if not os.stat(yapf_format_path).st_size == 0:
@@ -416,7 +418,7 @@ def linter_check(repo_root, linter_subfolder, linter_config_file=None):
     """ Main pre-commit function for calling code checking script. """
 
     if linter_config_file is not None and os.path.isfile(linter_config_file):
-        print("Found repo linter config: {}".format(linter_config_file))
+        # print("Found repo linter config: {}".format(linter_config_file))
         linter_config = read_linter_config(linter_config_file)
     else:
         linter_config = DEFAULT_CONFIG
@@ -424,11 +426,13 @@ def linter_check(repo_root, linter_subfolder, linter_config_file=None):
     cpplint_file = os.path.join(linter_subfolder, "cpplint.py")
     ascii_art_file = os.path.join(linter_subfolder, "ascii_art.py")
 
+    yapf_file = os.path.join(linter_subfolder, "yapf_config.rc")
+
     if os.path.isfile(os.path.join(repo_root, ".pylintrc")):
         pylintrc_file = os.path.join(repo_root, ".pylintrc")
     else:
         pylintrc_file = os.path.join(linter_subfolder, "pylint.rc")
-    print("Using pylint config file: {}".format(pylintrc_file))
+    # print("Using pylint config file: {}".format(pylintrc_file))
 
     # print("Found linter subfolder: {}".format(linter_subfolder))
     # print("Found ascii art file at: {}".format(ascii_art_file))
@@ -468,7 +472,7 @@ def linter_check(repo_root, linter_subfolder, linter_config_file=None):
             run_clang_format(repo_root, whitelisted_files, list_of_changed_staged_files)
 
         if linter_config['use_yapf']:
-            run_yapf_format(repo_root, whitelisted_files, list_of_changed_staged_files)
+            run_yapf_format(repo_root, whitelisted_files, list_of_changed_staged_files, yapf_file)
 
         # Use Google's C++ linter to check for compliance with Google style
         # guide.
@@ -477,7 +481,7 @@ def linter_check(repo_root, linter_subfolder, linter_config_file=None):
         else:
             cpp_lint_success = True
 
-        # Use pylint to check for comimpliance with Tensofrflow python
+        # Use pylint to check for compliance with Tensorflow python
         # style guide.
         if linter_config['use_pylint']:
             pylint_success = check_python_lint(repo_root, whitelisted_files, pylintrc_file)
@@ -486,7 +490,7 @@ def linter_check(repo_root, linter_subfolder, linter_config_file=None):
 
         if not (cpp_lint_success and pylint_success):
             print("=" * 80)
-            print("Commit not up to standards!")
+            print("Commit is not up to standards!")
             print("Please address the linter errors above.")
             print("=" * 80)
             if linter_config['block_commits']:
